==> rscheme_0.7.3pre.1.b39.orig.tar.gz: rs-0.7.3.1-b39/modules/start/present.scm <==
#|------------------------------------------------------------*-Scheme-*--|
 | File:    modules/start/present.scm
 |
 |          Copyright (C)1997-1999 Donovan Kolbly <d.kolbly@rscheme.org>
 |          as part of the RScheme project, licensed for free use.
 |          See <http://www.rscheme.org/> for the latest information.
 |
 | File version:     1.7
 | File mod date:    1999.01.05 21:03:29
 | System build:     v0.7.3.1-b39, 1999-12-25
 | Owned by module:  start
 |
 | Purpose:          Presentation banners
 `------------------------------------------------------------------------|#

(define *program* "RScheme")

;; `*version*' is really filled in at link time
(define *version* "RScheme (v0.7.3.1-b39, 1999-12-25)")

(define *license* "\nCopyright (C) 1995-1999 Donovan Kolbly <d.kolbly@rscheme.org>\nRScheme comes with ABSOLUTELY NO WARRANTY.\n")

(define (set-presentation! program version license)
  (set! *program* program)
  (set! *version* version)
  (set! *license* license)
  (values))

;; display the program name, version, and date,
;; and general license info
;;
;; we use the low-level stdio functions because
;; the high-level stuff hasn't been set up yet
;; (the high-level i/o library is set up by the initialization procs,
;; which at this point haven't been run yet)
;;
;; this is called by `start' if the system is not invoked in "quiet" mode

(define (greeting)
  (let ((s (stdout)))
    (fwrite/str s *version*)
    (if *license*
	(fwrite/str s *license*)
	(fwrite/str s "\n"))))

==> rscheme_0.7.3.4.b3.orig.tar.gz: rs-0.7.3.4-b3/modules/start/present.scm <==
#|------------------------------------------------------------*-Scheme-*--|
 | File:    modules/start/present.scm
 |
 |          Copyright (C)1997-2005 Donovan Kolbly <d.kolbly@rscheme.org>
 |          as part of the RScheme project, licensed for free use.
 |          See <http://www.rscheme.org/> for the latest information.
 |
 | File version:     1.9
 | File mod date:    2005-02-24 16:22:11
 | System build:     v0.7.3.4-b3u, 2006-04-10
 | Owned by module:  start
 |
 | Purpose:          Presentation banners
 `------------------------------------------------------------------------|#

(define *program* "RScheme")

;; `*version*' is really filled in at link time
(define *version* "RScheme (v0.7.3.4-b3u, 2006-04-10)")

(define *license* "\nCopyright (C) 1995-2005 Donovan Kolbly <d.kolbly@rscheme.org>\nRScheme comes with ABSOLUTELY NO WARRANTY.\n")

(define (set-presentation! program version license)
  (set! *program* program)
  (set! *version* version)
  (set! *license* license)
  (values))

;; display the program name, version, and date,
;; and general license info
;;
;; we use the low-level stdio functions because
;; the high-level stuff hasn't been set up yet
;; (the high-level i/o library is set up by the initialization procs,
;; which at this point haven't been run yet)
;;
;; this is called by `start' if the system is not invoked in "quiet" mode

(define (greeting)
  (let ((s (stdout)))
    (fwrite/str s *version*)
    (if *license*
	(fwrite/str s *license*)
	(fwrite/str s "\n"))))
